'use strict';

module.exports = TopPanel;

const React = require('react');
const SearchInput = require('./search');
const { contactIcon, downloadIcon, rocketIcon } = require('../nav-icons');

function TopPanel(props) {
  const includeSearch = props.includeSearch === undefined ? true : props.includeSearch;
  const downloadUrl = props.downloadUrl || '/download-center';
  const downloadJmpValue = props.downloadJmpValue || 'nav';
  const downloadJmp = downloadJmpValue === '' ? '' : `?jmp=${downloadJmpValue}`;

  return React.createElement(
    'div',
    { className: 'm-nav-top' },
    React.createElement(
      'ul',
      null,
      React.createElement(
        'div',
        { className: 'm-nav-top-links m-nav-flex-y m-nav-flex-nowrap' },
        props.sections.map(renderSection)
      ),
      React.createElement(
        'div',
        { className: 'm-nav-flex-y m-nav-flex-nowrap' },
        React.createElement(
          'a',
          { href: props.contactUrl || '/contact?jmp=nav' },
          React.createElement(
            'button',
            {
              className: 'm-nav-flex-xy m-nav-top-contact',
              style: !includeSearch ? { marginRight: '15px' } : null },
            contactIcon
          )
        ),
        includeSearch && React.createElement(SearchInput, { searchUrl: props.searchUrl || '/search?search=' }),
        React.createElement(
          'a',
          {
            id: 'mongodb-nav-hosting-btn',
            href: '/cloud/atlas?jmp=nav' },
          React.createElement(
            'button',
            { className: 'btn-small btn-hollow btn-hollow--light-green margin--left-xs m-nav-top-host' },
            React.createElement(
              'span',
              null,
              'Free Sandbox'
            ),
            rocketIcon
          )
        ),
        React.createElement(
          'a',
          {
            id: 'mongodb-nav-download-btn',
            href: `${props.host}${downloadUrl}${downloadJmp}`,
            target: props.host === '' ? '_self' : '_blank' },
          React.createElement(
            'button',
            { className: 'm-nav-top-dl' },
            React.createElement(
              'span',
              null,
              'Download'
            ),
            downloadIcon
          )
        )
      )
    )
  );
}

function renderSection(section, i) {
  return React.createElement(
    'a',
    {
      key: i,
      target: section.self ? '_self' : '_blank',
      href: section.href },
    React.createElement(
      'li',
      null,
      section.text
    )
  );
}