'use strict';

module.exports = Section;

const {Component, h} = require('preact');
const NavCTA = require('../nav-cta');

function Link(props) {
  const content = props.bold || props.link ? h(
    'strong',
    null,
    props.text
  ) : props.text;

  if (!props.href) {
    return h(
      'li',
      { className: props.className },
      content
    );
  }

  return h(
    'a',
    {
      style: props.style,
      href: props.href,
      className: props.className,
      target: props.newTab ? '_blank' : '_self' },
    h(
      'li',
      null,
      content
    )
  );
}

function Section(props) {
  return h(
    'div',
    { className: 'm-nav-flex-space' },
    props.cta && h(NavCTA, {
      first: props.count === 0,
      header: props.cta.header,
      links: props.cta.links }),
    (props.midSection.link ? [[props.midSection]] : []).concat(props.linkLists || []).map(function (links, i) {
      return h(
        'ul',
        { key: i },
        links.map(function (item, j) {
          return h(Link, {
            key: `${i}.${j}`,
            bold: item.bold,
            link: item.link,
            text: props.isMobile && item.mobileText ? item.mobileText : item.text,
            href: item.href,
            className: item.className,
            style: item.style,
            newTab: item.newTab });
        })
      );
    })
  );
}