module.exports = BottomPanel

const React = require('react')
const NavCTA = require('../nav-cta')

function BottomPanel (props) {
  return <div className='m-nav-bottom'>
    {props.sections.map((section, i) => {
      let cn = 'm-nav-bottom-list m-nav-flex-space'

      if (!props.isMobile && props.activeSection !== i) {
        cn += ' m-nav-bottom-list-inactive'
      }

      return <div key={i} className={cn}>
        {section.cta &&
        <NavCTA
          first={i === 0}
          header={section.cta.header}
          links={section.cta.links} />}

        {((props.midSections[i].link ? [[props.midSections[i]]] : [])
          .concat(section.linkLists || []))
          .map((links, i) =>
            <ul key={i}>
              {links.map((item, j) =>
                <Link
                  key={`${i}.${j}`}
                  bold={item.bold}
                  link={item.link}
                  text={props.isMobile && item.mobileText ? item.mobileText : item.text}
                  subText={item.subText}
                  href={item.href}
                  className={item.className}
                  style={item.style}
                  newTab={item.newTab} />
              )}
            </ul>
          )}
      </div>
    })}
  </div>
}

function Link (props) {
  const subText = props.subText
    ? <small>{props.subText}</small>
    : ''
  const content = props.bold || props.link
    ? <strong>{props.text}{subText}</strong>
    : <span>{props.text}{subText}</span>

  if (!props.href) {
    return <li className={props.className}>
      {content}
    </li>
  }

  return <a
    style={props.style}
    href={props.href}
    className={props.className}
    target={props.newTab ? '_blank' : '_self'}>
    <li>{content}</li>
  </a>
}
