module.exports = TopPanel

const React = require('react')
const SearchInput = require('./search')
const {contactIcon, downloadIcon, rocketIcon} = require('../nav-icons')

function TopPanel (props) {
  const includeSearch = props.includeSearch === undefined ? true : props.includeSearch
  const downloadUrl = props.downloadUrl || '/download-center'
  const downloadJmpValue = props.downloadJmpValue || 'nav'
  const downloadJmp = downloadJmpValue === '' ? '' : `?jmp=${downloadJmpValue}`

  return <div className='m-nav-top'>
    <ul>
      <div className='m-nav-top-links m-nav-flex-y m-nav-flex-nowrap'>
        {props.sections.map(renderSection)}
      </div>

      <div className='m-nav-flex-y m-nav-flex-nowrap'>
        <a href={props.contactUrl || '/contact?jmp=nav'}>
          <button
            className='m-nav-flex-xy m-nav-top-contact'
            style={!includeSearch ? { marginRight: '15px' } : null}>
            {contactIcon}
          </button>
        </a>

        {includeSearch &&
        <SearchInput searchUrl={props.searchUrl || '/search?search='} />}

        <a
          id='mongodb-nav-hosting-btn'
          href='/cloud/atlas?jmp=nav'>
          <button className='btn-small btn-hollow btn-hollow--light-green margin--left-xs m-nav-top-host'>
            <span>Free Sandbox</span>
            {rocketIcon}
          </button>
        </a>

        <a
          id='mongodb-nav-download-btn'
          href={`${props.host}${downloadUrl}${downloadJmp}`}
          target={props.host === '' ? '_self' : '_blank'}>
          <button className='m-nav-top-dl'>
            <span>Download</span>
            {downloadIcon}
          </button>
        </a>
      </div>
    </ul>
  </div>
}

function renderSection (section, i) {
  return <a
    key={i}
    target={section.self ? '_self' : '_blank'}
    href={section.href}>
    <li>{section.text}</li>
  </a>
}
